var gphoto2_port_result_8c =
[
    [ "_", "gphoto2-port-result_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "bindtextdomain", "gphoto2-port-result_8c.html#add6dfc1077058ff26d79cdb18099d58a", null ],
    [ "dcgettext", "gphoto2-port-result_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5", null ],
    [ "dgettext", "gphoto2-port-result_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07", null ],
    [ "gettext", "gphoto2-port-result_8c.html#a83b8be0887dede025766d25e2bb884c6", null ],
    [ "N_", "gphoto2-port-result_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "textdomain", "gphoto2-port-result_8c.html#a5f80e8482ab93869489531a8c7ce7006", null ],
    [ "gp_port_result_as_string", "gphoto2-port-result_8c.html#a42cb93c9a0e2ada0716ab6e89884f450", null ]
];